@@ -402,7 +402,7 @@ MainWidget::MainWidget ( TDEAboutData *about, bool tren, TQWidget *parent, const
  
 	TQTimer *t = new TQTimer ( this );
 	connect ( t, TQ_SIGNAL ( timeout() ), this, TQ_SLOT ( queryModState() ) );
-	t->start ( 500, FALSE );
+	t->start ( 500, false );
 
 	int padx= 554;
 	TQString txt[9] = { "Ho\nme", TQString::fromUtf8("▲"), "Pg\nUp",
