@@ -6,7 +6,7 @@
 
 class VButton : public TQPushButton
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	VButton(TQWidget *parent=0, const char *name=0);
